/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 1002 $
 * $Date: 2020-04-10 23:31:24 +0200 (Fri, 10 Apr 2020) $
 */
package at.lcm.bu21.general.dtypes.editor2.TDataModel;

import at.lcm.bu21.general.dtypes.TArray;
import at.lcm.bu21.general.dtypes.TData;
import at.lcm.bu21.general.dtypes.TDataException;
import at.lcm.bu21.general.dtypes.TNull;

/**
 * Representation of a TArrayModel - type
 * 
 * @author Johannes Kaisinger
 */
public class TArrayModel extends TDataParentModel {

	/** Data variable */
	private TArray data;

	/** Variable for child row position for data manipulation */
	private int childRow;

	/** Variable for child row position for data manipulation */
	private int childColumn;

	/**
	 * Create object with size 1,1
	 * 
	 */
	public TArrayModel() {
		try {
			this.data = new TArray(new int[] { 1, 1 });
		} catch (TDataException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Create object with given data (TArray)
	 * 
	 * @param data
	 *            Reference of data (TArray)
	 */
	public TArrayModel(TArray data) {

		this.data = data;
	}

	/**
	 * Get all data (TArray)
	 * 
	 * @return data Reference of data (TArray)
	 */
	public TArray getTArray() {
		return this.data;
	}

	/**
	 * Get all data (TData)
	 * 
	 * @return Data Reference of data (TData)
	 */
	@Override
	public TData getData() {
		return this.data;
	}

	/**
	 * Get a single child (TData)
	 * 
	 * @param row
	 *            Index of row of array
	 * @param column
	 *            Index of column of array
	 * 
	 * @return Child Reference of Child (TData)
	 */
	public TDataModel getChildModel(int row, int column) {
		try {
			this.childRow = row;
			this.childColumn = column;
			return TDataModel.createTDataModel(this.data.get(row, column));
		} catch (TDataException e) {
			return null;
		}
	}

	/**
	 * Get a single value as String
	 * 
	 * @param row
	 *            Index of row of array
	 * @param column
	 *            Index of column of array
	 * 
	 * @return Child Values of child as String
	 */
	public String getValue(int row, int column) {
		if ((row > -1) && (column > -1)) {
			try {
				return this.data.get(row, column).toString();
			} catch (TDataException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		return null;
	}

	/**
	 * Replace a child after editing
	 * 
	 * @param value
	 *            New value of child (TData)
	 * 
	 */
	@Override
	public void replaceChild(TData value) {
		this.data.set(this.childRow, this.childColumn, value);
	}

	@Override
	public String getChildName() {
		return "{" + this.childRow + "," + this.childColumn + "}";
	}

	/**
	 * Set a child value
	 * 
	 * @param row
	 *            Index of row of array
	 * @param column
	 *            Index of column of array
	 * 
	 * @param value
	 *            New value of child (TData)
	 * 
	 */
	public void set(int row, int column, TData value) {
		this.data.set(row, column, value);
	}

	/**
	 * Insert a empty row
	 * 
	 * @param row
	 *            Index of row of array (place of insert)
	 * 
	 */
	public void insertRow(int row) {

		for (int r = this.data.size()[0]; r > row; r--) {
			for (int c = 0; c < this.data.size()[1]; c++) {
				try {
					this.data.set(r, c, this.data.get(r - 1, c));
				} catch (TDataException e) {
				}
			}
		}

		for (int c = 0; c < this.data.size()[1]; c++) {
			this.data.set(row, c, new TNull());
		}
	}

	/**
	 * Insert a empty column
	 * 
	 * @param column
	 *            Index of column of array (place of insert)
	 * 
	 */
	public void insertColumn(int column) {

		for (int c = this.data.size()[1]; c > column; c--) {
			for (int r = 0; r < this.data.size()[0]; r++) {
				try {
					this.data.set(r, c, this.data.get(r, c - 1));
				} catch (TDataException e) {
				}
			}
		}

		for (int r = 0; r < this.data.size()[0]; r++) {
			this.data.set(r, column, new TNull());
		}
	}

	/**
	 * Delete a row
	 * 
	 * @param row
	 *            Index of row of array (place of delete)
	 * 
	 */
	public void deleteRow(int row) {

		final TArray temp = this.data;
		this.data = new TArray();

		int index = 0;
		for (int r = 0; r < temp.size()[0]; r++) {
			for (int c = 0; c < temp.size()[1]; c++) {
				try {
					if (r == row) {
						index = 1;
						if ((r + index) < temp.size()[0]) {
							this.data.set(r, c, temp.get(r + index, c));
						}
					} else if ((r + index) < temp.size()[0]) {
						this.data.set(r, c, temp.get(r + index, c));
					}
				} catch (final TDataException e) {
				}
			}
		}

	}

	/**
	 * Delete a column
	 * 
	 * @param column
	 *            Index of column of array (place of delete)
	 * 
	 */
	public void deleteColumn(int column) {

		final TArray temp = this.data;
		this.data = new TArray();

		for (int r = 0; r < temp.size()[0]; r++) {
			int index = 0;
			for (int c = 0; c < temp.size()[1]; c++) {
				try {
					if (c == column) {
						index = 1;
						if ((c + index) < temp.size()[1]) {
							this.data.set(r, c, temp.get(r, c + index));
						}
					} else if ((c + index) < temp.size()[1]) {
						this.data.set(r, c, temp.get(r, c + index));
					}
				} catch (final TDataException e) {
				}
			}
		}
	}
}
