/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.dtypes.sound;

import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.LineUnavailableException;
import javax.sound.sampled.SourceDataLine;

import at.lcm.bu21.general.dtypes.TPeriodic;
import at.lcm.bu21.general.utils.CloneException;

/**
 * Play sound of TPeriodic signal
 * 
 * @author gweidenholzer
 */
public class TPeriodicSound {

	/**
	 * @param signal
	 *            Periodic signal
	 * @param freq
	 *            Frequency (Hz)
	 * @param duration
	 *            Duration (sec.)
	 * @throws CloneException
	 *             Unable to clone (serialize)
	 * @throws LineUnavailableException
	 *             Audio exception
	 */
	public static void sound(TPeriodic signal, double freq, double duration)
			throws CloneException, LineUnavailableException {

		signal = signal.removeDC();
		signal = signal.scale(1 / signal.pp());

		double omega = freq * 2.0 * Math.PI;

		final int sampleRate = 16000;
		double ts = 1.0 / sampleRate;

		int samples = (int) (duration * sampleRate);

		final AudioFormat af = new AudioFormat(sampleRate, 8, 1, true, true);
		SourceDataLine line = AudioSystem.getSourceDataLine(af);
		line.open(af);
		line.start();

		byte[] buf = new byte[samples];

		for (int i = 0; i < samples; i++) {

			double angle = omega * i * ts;
			byte val = (byte) (signal.valueAt(angle) * 127.0);
			buf[i] = val;
		}

		line.write(buf, 0, samples);
		line.drain();
		line.close();

	}

}
