/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.math.autodiff;

/**
 * Logarithm function
 * 
 * @author Gnther Weidenholzer
 */
public class Ln extends Func {

	/**
	 * Create logarithm function
	 * 
	 * @param arg
	 *            Argument of logarithm
	 */
	public Ln(Func arg) {
		super(arg);
	}

	@Override
	public double value() throws Exception {
		return Math.log(this.getArg(0).value());
	}

	/**
	 * Derivation of logarithm
	 * 
	 * @param arg
	 *            Argument for derivative
	 * @return Derivative function
	 * @throws Exception
	 *             Derivative exception
	 */
	@Override
	public Func derivativeArg(Func arg) throws Exception {

		return new Pow(arg, -1.0);
	}

}
