/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.utils;

import java.io.File;

/**
 * Convert image format
 * 
 * @author Werner Koppelsttter
 */
public class ImageConvert {

	/**
	 * Get converter for emf-files
	 * 
	 * @return Converter
	 */
	public static File getEmfConverter() {
		File converter = null;

		// converter = FileUtils.getFile(System.getenv("Program Files"),
		// "Inkscape", "inkscape.exe");
		//
		// if ((converter == null) || !converter.exists()) {
		// converter = FileUtils.getFile(System.getenv("Program Files(x86)"),
		// "Inkscape", "inkscape.exe");
		// }
		//
		// if ((converter == null) || !converter.exists()) {
		converter = FileUtils.getFile(System.getenv("ProgramFiles"), "Metafile to EPS Converter", "metafile2eps.exe");
		// }

		if ((converter == null) || !converter.exists()) {
			converter = FileUtils.getFile(System.getenv("ProgramFiles(x86)"), "Metafile to EPS Converter",
					"metafile2eps.exe");
		}

		if ((converter == null) || !converter.exists()) {
			converter = ImageConvert.getLyXConverter(new File(System.getenv("ProgramFiles")));
		}

		if ((converter == null) || !converter.exists()) {
			converter = ImageConvert.getLyXConverter(new File(System.getenv("ProgramFiles(x86)")));
		}

		if ((converter != null) && !converter.exists()) {
			converter = null;
		}

		return converter;
	}

	/**
	 * Get Converter from emf to eps
	 * 
	 * @param path
	 *            Program path to search
	 * @return Path to converter
	 */
	private static File getLyXConverter(File path) {
		File converter = null, con;

		if (path != null) {
			for (File f : path.listFiles()) {
				if (f.isDirectory() && f.getName().toLowerCase().startsWith("lyx")) {
					con = new File(new File(f, "bin"), "metafile2eps.exe");
					if (con.exists()) {
						converter = con;
						break;
					}
				}
			}
		}

		return converter;
	}

	/**
	 * Convert from emf to pdf
	 * 
	 * @param file
	 *            Emf-file to convert
	 * @return Pdf result-file
	 */
	public static File emf2pdf(File file) {
		File converter, result = null;
		ProcessBuilder cmd;
		Process process;
		String name;

		if ((file != null) && (file.getName().toLowerCase().endsWith(".emf"))) {
			converter = ImageConvert.getEmfConverter();
			if (converter != null) {
				if (converter.getName().equalsIgnoreCase("inkscape.exe")) {
					name = file.getName();
					name = name.substring(0, name.length() - 4);
					result = new File(file.getParentFile(), name + ".pdf");

					cmd = new ProcessBuilder(converter.getPath(), "--file=" + file.getName(), "--export-area-drawing",
							"--without-gui", "--export-pdf=" + result.getName());
					cmd.directory(file.getParentFile());
					try {
						process = cmd.start();
						process.waitFor();
						if (!result.exists()) {
							result = null;
						}

					} catch (Exception e) {
						result = null;
					}
				} else {
					result = ImageConvert.eps2pdf(ImageConvert.emf2eps(file));
				}
			}
		}

		return result;
	}

	/**
	 * Convert from emf to eps
	 * 
	 * @param file
	 *            Emf-file to convert
	 * @return Eps result-file
	 */
	public static File emf2eps(File file) {
		File converter, result = null;
		ProcessBuilder cmd;
		Process process;
		String name;

		if ((file != null) && (file.getName().toLowerCase().endsWith(".emf"))) {

			converter = ImageConvert.getEmfConverter();

			if (converter != null) {
				name = file.getName();
				name = name.substring(0, name.length() - 4);
				result = new File(file.getParentFile(), name + ".eps");

				if (converter.getName().equalsIgnoreCase("inkscape.exe")) {
					cmd = new ProcessBuilder(converter.getPath(), "--file=" + file.getName(), "--export-area-drawing",
							"--without-gui", "--export-eps=" + result.getName());
				} else {
					cmd = new ProcessBuilder(converter.getPath(), file.getName(), result.getName());
				}
				cmd.directory(file.getParentFile());
				try {
					process = cmd.start();
					process.waitFor();
					if (!result.exists()) {
						result = null;
					}

				} catch (Exception e) {
					result = null;
				}
			}
		}

		return result;
	}

	/**
	 * Convert from eps to pdf
	 * 
	 * @param file
	 *            eps-file to convert
	 * @return Pdf result-file
	 */
	public static File eps2pdf(File file) {
		File result = null;
		ProcessBuilder cmd;
		Process process;
		String name;

		if (file != null) {
			if (file.getName().toLowerCase().endsWith(".eps")) {
				name = file.getName();
				name = name.substring(0, name.length() - 4);
				result = new File(file.getParentFile(), name + ".pdf");

			} else if (file.getName().toLowerCase().endsWith(".ps")) {
				name = file.getName();
				name = name.substring(0, name.length() - 3);
				result = new File(file.getParentFile(), name + ".pdf");
			}

			if (result != null) {
				cmd = new ProcessBuilder("epstopdf", file.getName(), "--outfile=\"" + result.getName() + "\"");
				cmd.directory(file.getParentFile());
				try {
					process = cmd.start();
					process.waitFor();
					if (!result.exists()) {
						result = null;
					}

				} catch (Exception e) {
					result = null;
				}
			}
		}
		return result;
	}

}
