/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.utils;

import java.io.Serializable;

/**
 * Group to object into a pair-object
 * 
 * @param <F>
 *            First object in pair
 * @param <S>
 *            Second object in pair
 * 
 * @author Werner Koppelsttter
 */
public class Pair<F, S> implements Serializable {

	/** First object */
	F first;

	/** Second objext */
	S second;

	/**
	 * Create pair object
	 * 
	 * @param first
	 *            First object
	 * @param second
	 *            Second object
	 */
	public Pair(F first, S second) {
		this.first = first;
		this.second = second;
	}

	/**
	 * Get first object
	 * 
	 * @return First object
	 */
	public F getFirst() {
		return this.first;
	}

	/**
	 * Set first object
	 * 
	 * @param first
	 *            Object to set
	 */
	public void setFirst(F first) {
		this.first = first;
	}

	/**
	 * Get second object
	 * 
	 * @return Second object
	 */
	public S getSecond() {
		return this.second;
	}

	/**
	 * Set second object
	 * 
	 * @param second
	 *            Object to set
	 */
	public void setSecond(S second) {
		this.second = second;
	}

	@Override
	public String toString() {
		return "(" + this.first + "," + this.second + ")";
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (this.getClass() != obj.getClass()) {
			return false;
		}
		@SuppressWarnings("rawtypes")
		Pair other = (Pair) obj;
		if (this.first == null) {
			if (other.first != null) {
				return false;
			}
		} else if (!this.first.equals(other.first)) {
			return false;
		}
		if (this.second == null) {
			if (other.second != null) {
				return false;
			}
		} else if (!this.second.equals(other.second)) {
			return false;
		}
		return true;
	}
}
