# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 1041 $
$LastChangedDate:: 2021-02-04 13:55:24 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import pkgutil
from nose.plugins import Plugin


class LoadCoverageModules(Plugin):
    """
    Plugin that loads all modules in the specified directory before running unittests
    so all modules appear in the coverage report,
    even the modules which would otherwise not be touched by the unittests.
    """
    enabled = True
    name = 'load_cov_modules'
    score = 100

    def __init__(self, cov_dir: str):
        """

        Parameters
        ----------
        cov_dir: str
            Force import of modules of this directory and sub-directories
        """
        super().__init__()
        self.cov_dir = cov_dir

    def options(self, parser, env):
        super().options(parser, env)

    def configure(self, options, conf):
        """Configure plugin. Plugin is enabled by default.
        """
        super().configure(options, conf)
        self.auto_import()

    def auto_import(self):
        """Import all modules in the source directory to include all modules in the coverage report"""
        src_dir = os.path.join(self.cov_dir)
        for _, name, _ in pkgutil.walk_packages([src_dir, ]):
            if not name.startswith('setup'):
                try:
                    __import__(name)
                except Exception as ex:
                    print('Import of "{}" failed! => {} '.format(name, ex))
