/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.center.utils.simulate;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;

import at.lcm.bu21.magopt.structure.simulate.SimulateAll;
import at.lcm.bu21.magopt.structure.simulate.SimulateEvent;
import at.lcm.bu21.magopt.structure.simulate.SimulateListener;
import jobmanager.JobDesc;

public class SimulateView extends JPanel
		implements ActionListener, SimulateListener {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	private SimulateAll sim;

	private JCheckBox mRunSim;

	private JCheckBox mRemoteCompute;

	private JCheckBox mOptimize;

	private ProgressPanel mProgress;

	private JLabel mStatus;

	private JButton mStart;

	private JButton mStop;

	private JButton mJobManager;

	public SimulateView(SimulateAll sim) {
		super();
		this.sim = sim;

		this.init();
		this.mProgress.setWeight(
				new int[] { sim.getNumFinished(), sim.getNumIncomplete(),
						sim.getNumError(), sim.getNumNotInitialized() });
		sim.addSimulateListener(this);
	}

	private void init() {
		GroupLayout layout = new GroupLayout(this);
		this.setLayout(layout);
		layout.setAutoCreateGaps(true);
		layout.setAutoCreateContainerGaps(true);

		/* run simulation */
		JLabel lRunSim = new JLabel("Start Simulation:");
		this.mRunSim = new JCheckBox();
		this.mRunSim.setSelected(this.sim.getRunSimulation());
		this.mRunSim.addActionListener(this);

		/* remote compute */
		JLabel lRemoteCompute = new JLabel("Remote Compute:");
		this.mRemoteCompute = new JCheckBox();
		this.mRemoteCompute.setSelected(this.sim.getRemoteCompute());
		this.mRemoteCompute.addActionListener(this);

		/* optimize */
		JLabel lOptimize = new JLabel("Optimize:");
		this.mOptimize = new JCheckBox();
		this.mOptimize.setSelected(this.sim.getOptimize());
		this.mOptimize.addActionListener(this);

		/* progress */
		JLabel lProgress = new JLabel("Progress:");
		this.mProgress = new ProgressPanel(new Color[] { Color.GREEN,
				Color.ORANGE, Color.RED, Color.GRAY });

		/* status */
		JLabel lStatus = new JLabel("Status:");
		this.mStatus = new JLabel("Idle");

		/* start */
		this.mStart = new JButton("Start");
		this.mStart.setEnabled(!this.sim.isStart());
		this.mStart.addActionListener(this);

		/* stop */
		this.mStop = new JButton("Stop");
		this.mStop.setEnabled(this.sim.isStart() && !this.sim.isStop());
		this.mStop.addActionListener(this);

		/*  */
		this.mJobManager = new JButton("JobManager");
		this.mJobManager.addActionListener(this);

		/* config group layout */
		layout.setHorizontalGroup(layout.createSequentialGroup()
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(lRunSim).addComponent(lRemoteCompute)
						.addComponent(lOptimize).addComponent(lProgress)
						.addComponent(lStatus))
				.addGap(20)
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(this.mRunSim)
						.addComponent(this.mRemoteCompute)
						.addComponent(this.mOptimize)
						.addComponent(this.mProgress).addComponent(this.mStatus)
						.addGroup(layout.createSequentialGroup()
								.addComponent(this.mStart)
								.addComponent(this.mStop)
								.addComponent(this.mJobManager))));
		layout.setVerticalGroup(layout.createSequentialGroup()
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lRunSim).addComponent(this.mRunSim))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lRemoteCompute)
						.addComponent(this.mRemoteCompute))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lOptimize).addComponent(this.mOptimize))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lProgress).addComponent(this.mProgress))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(lStatus).addComponent(this.mStatus))
				.addGroup(layout
						.createParallelGroup(GroupLayout.Alignment.BASELINE)
						.addComponent(this.mStart).addComponent(this.mStop)
						.addComponent(this.mJobManager)));

	}

	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == this.mRunSim) {
			this.sim.setRunSimulation(this.mRunSim.isSelected());
		} else if (e.getSource() == this.mRemoteCompute) {
			this.sim.setRemoteCompute(this.mRemoteCompute.isSelected());
		} else if (e.getSource() == this.mOptimize) {
			this.sim.setOptimize(this.mOptimize.isSelected());
		} else if (e.getSource() == this.mStart) {
			this.sim.start();
		} else if (e.getSource() == this.mStop) {
			this.sim.stop();
		} else if (e.getSource() == this.mJobManager) {
			new Thread() {
				@Override
				public void run() {
					JobDesc.setVisible(true);
				}
			}.start();
		}
	}

	@Override
	public void simulateChanged(SimulateEvent event) {
		switch (event.getType()) {
		case RUN_SIM_CHANGED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mRunSim.setSelected(
							SimulateView.this.sim.getRunSimulation());
				}
			});
			break;
		case REMOTE_COMPUTE_CHANGED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mRemoteCompute.setSelected(
							SimulateView.this.sim.getRemoteCompute());
				}
			});
			break;
		case OPTIMIZE_CHANGED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mOptimize
							.setSelected(SimulateView.this.sim.getOptimize());
				}
			});
			break;
		case TIMEOUT_CHANGED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					// FIXME Timeout
					System.out.println(
							"Timeout:\t" + SimulateView.this.sim.getTimeout());
				}
			});
			break;
		case STATUS_CHANGED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mStatus
							.setText(SimulateView.this.sim.getStatus());
					SimulateView.this.mProgress.setWeight(new int[] {
							SimulateView.this.sim.getNumFinished(),
							SimulateView.this.sim.getNumIncomplete(),
							SimulateView.this.sim.getNumError(),
							SimulateView.this.sim.getNumNotInitialized() });
				}
			});
			break;
		case START:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mStart.setEnabled(false);
				}
			});
			break;
		case STARTED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mStop.setEnabled(true);
				}
			});
			break;
		case STOP:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mStop.setEnabled(false);
				}
			});
			break;
		case STOPPED:
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					SimulateView.this.mStart.setEnabled(true);
				}
			});
			break;
		}

	}
}
