/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.center.views;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.SwingUtilities;
import javax.swing.border.EmptyBorder;

import at.lcm.symspace.center.CenterController;
import at.lcm.symspace.gui.views.ToolBar;

public class CenterStatusBar extends ToolBar {
	CenterController controller;

	JProgressBar progressBar;

	public CenterStatusBar(CenterController controller) {
		JPanel panel;

		this.controller = controller;

		// define progress-bar
		this.progressBar = new JProgressBar();
		this.progressBar.setString("Status");
		this.progressBar.setMinimum(0);
		this.progressBar.setIndeterminate(true);
		this.progressBar.setStringPainted(true);
		this.progressBar.setVisible(false);

		// TODO Define layout Manager
		// define size when progress-bar is invisible
		panel = new JPanel() {
			@Override
			public Dimension getMinimumSize() {
				Dimension dim = super.getMinimumSize();
				if (dim.height < CenterStatusBar.this.progressBar.getMinimumSize().height) {
					dim.height = CenterStatusBar.this.progressBar.getMinimumSize().height;
				}
				if (dim.width < CenterStatusBar.this.progressBar.getMinimumSize().width) {
					dim.width = CenterStatusBar.this.progressBar.getMinimumSize().width;
				}
				return dim;
			}

			@Override
			public Dimension getMaximumSize() {
				Dimension dim = super.getMaximumSize();
				if (dim.height < CenterStatusBar.this.progressBar.getMaximumSize().height) {
					dim.height = CenterStatusBar.this.progressBar.getMaximumSize().height;
				}
				if (dim.width < CenterStatusBar.this.progressBar.getMaximumSize().width) {
					dim.width = CenterStatusBar.this.progressBar.getMaximumSize().width;
				}
				return dim;
			}

			@Override
			public Dimension getPreferredSize() {
				Dimension dim = super.getPreferredSize();
				if (dim.height < CenterStatusBar.this.progressBar.getPreferredSize().height) {
					dim.height = CenterStatusBar.this.progressBar.getPreferredSize().height;
				}
				if (dim.width < CenterStatusBar.this.progressBar.getPreferredSize().width) {
					dim.width = CenterStatusBar.this.progressBar.getPreferredSize().width;
				}
				return dim;
			}

		};
		panel.setLayout(new BorderLayout());
		panel.setBorder(new EmptyBorder(2, 2, 2, 2));
		panel.add(this.progressBar, BorderLayout.EAST);

		this.add(panel);
	}

	public void showProgressBar(final String init, final int max) {
		SwingUtilities.invokeLater(new Runnable() {
			@Override
			public void run() {
				if (max > 0) {
					CenterStatusBar.this.progressBar.setMaximum(max);
					CenterStatusBar.this.progressBar.setIndeterminate(false);
				} else {
					CenterStatusBar.this.progressBar.setIndeterminate(true);
				}
				CenterStatusBar.this.progressBar.setVisible(true);
				CenterStatusBar.this.progressBar.setString(init);
			}
		});
	}

	public void updateProgressBar(final int val, final String status) {
		SwingUtilities.invokeLater(new Runnable() {
			@Override
			public void run() {
				CenterStatusBar.this.progressBar.setValue(val);
				CenterStatusBar.this.progressBar.setString(status);
			}
		});

	}

	public void hideProgressBar() {
		SwingUtilities.invokeLater(new Runnable() {
			@Override
			public void run() {
				CenterStatusBar.this.progressBar.setVisible(false);
			}
		});

	}

	@Override
	public void refresh() {

	}
}
