/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.docu;

import java.io.Serializable;

/**
 * Model of report-structure
 * 
 * @author Werner Koppelsttter
 */
public class ReportStructure implements Serializable {

	/** Serializable identifier */
	private static final long serialVersionUID = 1L;

	/** State of summary */
	protected boolean summary = true;
	/** State of template */
	protected boolean template = true;
	/** State of info */
	protected boolean info = false;
	/** State of import/export */
	protected boolean imExport = false;
	/** State of used/set */
	protected boolean usedSet = false;
	/** State of files */
	protected boolean files = false;
	/** State of function */
	protected boolean function = false;
	/** State of packages */
	protected boolean packages = false;
	/** State of data-sheet */
	protected boolean datasheets = true;

	/**
	 * Get state of summary
	 * 
	 * @return State
	 */
	public boolean getSummary() {
		return this.summary;
	}

	/**
	 * Set state of summary
	 * 
	 * @param val
	 *            State
	 */
	public void setSummary(boolean val) {
		this.summary = val;
	}

	/**
	 * Get state of detail
	 * 
	 * @return State
	 */
	public boolean getDetail() {
		return this.getTemplate() || this.getParameter();
	}

	/**
	 * Set state of detail
	 * 
	 * @param val
	 *            State
	 */
	public void setDetail(boolean val) {
		this.setTemplate(val);
		this.setParameter(val);
	}

	/**
	 * Get state of template
	 * 
	 * @return State
	 */
	public boolean getTemplate() {
		return this.template;
	}

	/**
	 * Set state of template
	 * 
	 * @param val
	 *            State
	 */
	public void setTemplate(boolean val) {
		this.template = val;
	}

	/**
	 * Get state of parameter
	 * 
	 * @return State
	 */
	public boolean getParameter() {
		return this.getInfo() || this.getImExport() || this.getUsedSet()
				|| this.getFiles();
	}

	/**
	 * Set state of parameter
	 * 
	 * @param val
	 *            State
	 */
	public void setParameter(boolean val) {
		this.setInfo(val);
		this.setImExport(val);
		this.setUsedSet(val);
		this.setFiles(val);
	}

	/**
	 * Get state of info
	 * 
	 * @return State
	 */
	public boolean getInfo() {
		return this.info;
	}

	/**
	 * Set state of info
	 * 
	 * @param val
	 *            State
	 */
	public void setInfo(boolean val) {
		this.info = val;
	}

	/**
	 * Get state of import/export
	 * 
	 * @return State
	 */
	public boolean getImExport() {
		return this.imExport;
	}

	/**
	 * Set state of import/export
	 * 
	 * @param val
	 *            State
	 */
	public void setImExport(boolean val) {
		this.imExport = val;
	}

	/**
	 * Get state of used/set
	 * 
	 * @return State
	 */
	public boolean getUsedSet() {
		return this.usedSet;
	}

	/**
	 * Set state of used/set
	 * 
	 * @param val
	 *            State
	 */
	public void setUsedSet(boolean val) {
		this.usedSet = val;
	}

	/**
	 * Get state of files
	 * 
	 * @return State
	 */
	public boolean getFiles() {
		return this.files;
	}

	/**
	 * Set state of files
	 * 
	 * @param val
	 *            State
	 */
	public void setFiles(boolean val) {
		this.files = val;
	}

	/**
	 * Get state of function
	 * 
	 * @return State
	 */
	public boolean getFunction() {
		return this.function;
	}

	/**
	 * Set state of function
	 * 
	 * @param val
	 *            State
	 */
	public void setFunction(boolean val) {
		this.function = val;
	}

	/**
	 * Get state of packages
	 * 
	 * @return State
	 */
	public boolean getPackage() {
		return this.packages;
	}

	/**
	 * Set state of packages
	 * 
	 * @param val
	 *            State
	 */
	public void setPackage(boolean val) {
		this.packages = val;
	}

	/**
	 * Get state of data-sheets
	 * 
	 * @return State
	 */
	public boolean getDatasheet() {
		return this.datasheets;
	}

	/**
	 * Set state of data-sheets
	 * 
	 * @param val
	 *            State
	 */
	public void setDatasheet(boolean val) {
		this.datasheets = val;
	}

}
