/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.rmi.Remote;
import java.rmi.RemoteException;
import java.util.Map;

/**
 * Interface for Parameter which has a function to update
 * 
 * @author Werner Koppelsttter
 */
public interface IFunction extends Remote, IDependency {

	/**
	 * Get the status of update. Return true if a update is necessary and
	 * otherwise false
	 * 
	 * @return Status of update
	 * @throws RemoteException
	 */
	public boolean getUpdateRequired() throws RemoteException;

	/**
	 * Get update-status
	 * 
	 * @param index
	 *            Index of dataset
	 * @return update-status
	 * @throws RemoteException
	 */
	public boolean getUpdateRequired(int index) throws RemoteException;

	/**
	 * Set the status of update. Value true if a update is required and false if
	 * no update is required
	 * 
	 * @param update
	 *            Update-status
	 * @throws RemoteException
	 */
	public void setUpdateRequired(boolean update) throws RemoteException;

	/**
	 * Set the status of update for given index. Value true if a update is
	 * required and false if no update is required
	 * 
	 * @param index
	 *            Index of dataset
	 * @param update
	 *            Update-status
	 * @throws RemoteException
	 */
	public void setUpdateRequired(int index, boolean update)
			throws RemoteException;

	/**
	 * Reset Function
	 * 
	 * @throws RemoteException
	 */
	public void reset() throws RemoteException;

	/**
	 * Check if function is enable
	 * 
	 * @return Is function enable
	 * @throws RemoteException
	 */
	public boolean isEnable() throws RemoteException;

	/**
	 * Update function
	 * 
	 * @param args
	 *            Arguments of caller (Control flags)
	 * @return Status
	 * @throws Exception
	 * @throws RemoteException
	 */
	public int update(Map<String, Object> args) throws Exception,
			RemoteException;

}
