/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 10034 $
 * $Date: 2020-10-21 18:25:19 +0200 (Wed, 21 Oct 2020) $
 */
package at.lcm.bu21.magopt.structure;

/**
 * Types of parameter values for adding to parameter-sets
 * 
 * @author Werner Koppelsttter
 */
public enum ParamSetKey {
	/** Data of parameter */
	DATA(false),
	/** Modified-flag */
	MODIFIED(false),
	/** Update-required-flag */
	UPDATEREQUIRED(false),
	/** Uncertain-flag */
	UNCERTAIN(false),
	/** Warning-flag */
	WARNING(false),
	/** Error-flag */
	ERROR(false),
	/** Incomplete-flag */
	INCOMPLETE(false),
	/** Path of directory */
	DIRECTORY(false),
	/** Reference location of relative directory */
	LOCATION(false),
	/** Name of file */
	FILE(false),
	/** Checksum of file */
	CHECKSUM(false),
	/** Modified-date for checksum of file */
	CHECKSUM_MODIFIED(true),
	/** Reset-flag */
	RESET(true);

	/** Save value */
	private final boolean temporary;

	/**
	 * Create enumeration
	 * 
	 * @param temporary Temporary value
	 */
	private ParamSetKey(boolean temporary) {
		this.temporary = temporary;
	}

	/**
	 * Check if temporary
	 * 
	 * @return Temporary
	 */
	boolean isTemporary() {
		return this.temporary;
	}

}
