/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.client;

import java.rmi.RemoteException;
import java.util.Map;

import at.lcm.bu21.magopt.structure.DependDirection;
import at.lcm.bu21.magopt.structure.IDepend;
import at.lcm.bu21.magopt.structure.IDependItem;
import at.lcm.bu21.magopt.structure.PortDesc;

/**
 * Client adapter for depend interface
 * 
 * @author Werner Koppelsttter
 */
public class CDepend implements IDepend {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Depend class */
	private IDepend depend;

	/**
	 * Create client adapter for depend interface
	 * 
	 * @param depend
	 *            Depend
	 */
	public CDepend(IDepend depend) {
		this.depend = depend;
	}

	@Override
	public IDependItem[] getImports() throws RemoteException {
		IDependItem[] items;
		IDependItem[] rmiItems;

		items = this.depend.getImports();
		rmiItems = new IDependItem[items.length];
		for (int k = 0; k < items.length; k++) {
			rmiItems[k] = items[k].getClientImpl();
		}

		return rmiItems;
	}

	@Override
	public IDependItem[] getExports() throws RemoteException {
		IDependItem[] items;
		IDependItem[] rmiItems;

		items = this.depend.getExports();
		rmiItems = new IDependItem[items.length];
		for (int k = 0; k < items.length; k++) {
			rmiItems[k] = items[k].getClientImpl();
		}

		return rmiItems;
	}

	@Override
	public void setImportVars(PortDesc[] vars) throws RemoteException {
		this.depend.setImportVars(vars);
	}

	@Override
	public void setExportVars(PortDesc[] vars) throws RemoteException {
		this.depend.setExportVars(vars);
	}

	@Override
	public void setImportAssignments(String[][] vars) throws RemoteException {
		this.depend.setImportAssignments(vars);
	}

	@Override
	public void setImportAssignmentsMap(Map<String, String> vars)
			throws RemoteException {
		this.depend.setImportAssignmentsMap(vars);
	}

	@Override
	public void setExportAssignments(String[][] vars) throws RemoteException {
		this.depend.setExportAssignments(vars);
	}

	@Override
	public void setExportAssignmentsMap(Map<String, String> vars)
			throws RemoteException {
		this.depend.setExportAssignmentsMap(vars);
	}

	@Override
	public int getDependsLength(DependDirection direction)
			throws RemoteException {
		return this.depend.getDependsLength(direction);
	}

	@Override
	public IDependItem getDepend(DependDirection direction, int index)
			throws RemoteException {
		return this.depend.getDepend(direction, index).getClientImpl();
	}

	@Override
	public void setAssignment(String var, String param,
			DependDirection direction) throws RemoteException {
		this.depend.setAssignment(var, param, direction);
	}

	@Override
	public CDepend getClientImpl() {
		return this;
	}
}
