/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.client;

import java.rmi.RemoteException;
import java.util.List;

import at.lcm.bu21.magopt.structure.IParamPythonFunction;

/**
 * Client adapter for matlab-function interface
 * 
 * @author Werner Koppelsttter
 */
public class CParamPythonFunction extends CParamFunction
		implements IParamPythonFunction {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Matlab-function class */
	private IParamPythonFunction param;

	/**
	 * Create client adapter for matlab-function interface
	 * 
	 * @param param
	 *            Matlab function
	 */
	public CParamPythonFunction(IParamPythonFunction param) {
		super(param);
		this.param = param;
	}

	@Override
	public void reset() throws RemoteException {
		this.param.reset();
	}

	@Override
	public void refreshDependency() throws RemoteException {
		this.param.refreshDependency();
	}

	@Override
	public void edit() throws RemoteException {
		this.param.edit();
	}

	@Override
	public void infoWithStack(String message, List<StackTraceElement> stack)
			throws RemoteException {
		this.param.infoWithStack(message, stack);
	}

	@Override
	public void warningWithStack(String message, List<StackTraceElement> stack)
			throws RemoteException {
		this.param.warningWithStack(message, stack);
	}

	@Override
	public void errorWithStack(String message, List<StackTraceElement> stack)
			throws RemoteException {
		this.param.errorWithStack(message, stack);
	}

	@Override
	public CParamPythonFunction getClientImpl() {
		return this;
	}
}
