/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import java.text.SimpleDateFormat;
import java.util.Date;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_16.
 * 
 * - Add dataset-index to ParamMaterial
 * 
 * @author Werner Koppelsttter
 */
public class Converter_16 {
	/** Date-formater */
	private static SimpleDateFormat sdf = new SimpleDateFormat(
			"dd-MM-yyyy HH:mm");

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {
		// Convert Parameter
		if (Converter_16.changeMaterial(node)) {
			Converter_16.addWarning(node);
		}

		return node;
	}

	/**
	 * Change material to constant
	 * 
	 * @param node
	 *            Node to update
	 * @return Structure changed
	 */
	private static boolean changeMaterial(XMLNode node) {
		XMLNode item;
		boolean changed = false;

		if (node.getName().compareTo("ParamMaterial") == 0) {
			changed = true;
			node.rmNode(1);
			node.rmNode(1);

			// add dataset-id
			item = new XMLNode("DSID");
			item.setText("-1");
			node.addNode(item);
			// add material-class
			item = new XMLNode("MCName");
			item.setText("---");
			node.addNode(item);
			// add material
			item = new XMLNode("MName");
			item.setText("---");
			node.addNode(item);
			// add dataset
			item = new XMLNode("DSName");
			item.setText("---");
			node.addNode(item);

		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			changed |= Converter_16.changeMaterial(n);
		}

		return changed;
	}

	/**
	 * Add Warning to the event-logs
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void addWarning(XMLNode node) {
		XMLNode item, entry;

		if (node.getName().compareTo("EventBuffer") == 0) {
			item = new XMLNode("EventWarning");
			node.addNode(item);

			entry = new XMLNode("Message");
			entry.setText("!!! Please update material parameters !!!");
			item.addNode(entry);

			entry = new XMLNode("Date");
			entry.setText(Converter_16.sdf.format(new Date()));
			item.addNode(entry);

			entry = new XMLNode("Identifier");
			item.addNode(entry);

			entry = new XMLNode("Stack");
			item.addNode(entry);
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_16.addWarning(n);
		}
	}

}
