/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */

package at.lcm.bu21.magopt.structure.ipython;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import org.json.simple.JSONAware;
import org.json.simple.JSONObject;
import org.json.simple.JSONValue;

/**
 * 
 *
 * @author gweidenholzer
 */
public class MessageHeader implements JSONAware {

	String msg_id;
	String msg_type;
	String session_id;
	String username;
	String date;
	String protocol_version;

	static final String PROTOCOL_VERSION = "5.0";

	/**
	 * Build a header for a message of the given type
	 * 
	 * @param kernel
	 *            session object
	 * @param msg_type
	 *            the message type
	 */
	public MessageHeader(KernelConnection kernel, String msg_type) {

		this.msg_id = UUID.randomUUID().toString();
		this.msg_type = msg_type;
		this.session_id = kernel.id;
		this.username = kernel.username;
		SimpleDateFormat sdf = new SimpleDateFormat(
				"yyyy-MM-dd'T'HH:mm:ss.SSS");
		this.date = sdf.format(new Date());
		this.protocol_version = MessageHeader.PROTOCOL_VERSION;

	}

	/**
	 * Constructor using serialized data
	 * 
	 * @param serialized_header
	 * @throws Exception
	 */
	public MessageHeader(byte[] serialized_header) throws Exception {

		JSONObject h = (JSONObject) Message.unpack(serialized_header);

		if (h.isEmpty()) {
			throw new Exception("Empty header");
		}

		this.msg_id = (String) h.get("msg_id");
		this.msg_type = (String) h.get("msg_type");
		this.session_id = (String) h.get("session");
		this.username = (String) h.get("username");
		this.date = (String) h.get("date");
		this.protocol_version = (String) h.get("version");

	}

	/**
	 * create JSON representation
	 */
	@Override
	public String toJSONString() {

		Map<String, String> map = new HashMap<String, String>();

		map.put("msg_id", this.msg_id);
		map.put("msg_type", this.msg_type);
		map.put("username", this.username);
		map.put("session", this.session_id);
		map.put("date", this.date);
		map.put("version", this.protocol_version);

		return JSONValue.toJSONString(map);
	}
}
