/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.rmi;

import java.rmi.RemoteException;
import java.util.Map;

import at.lcm.bu21.magopt.structure.IDepend;
import at.lcm.bu21.magopt.structure.IParamCollector;
import at.lcm.bu21.magopt.structure.ParamCollector;
import at.lcm.bu21.magopt.structure.client.CParamCollector;

/**
 * RMI adapter for material
 * 
 * @author Werner Koppelsttter
 */
public class RParamCollector extends RParamContainer implements IParamCollector {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Material class */
	private ParamCollector param;

	/**
	 * Create rmi adapter for material
	 * 
	 * @param param
	 *            Material
	 * @throws RemoteException
	 */
	public RParamCollector(ParamCollector param) throws RemoteException {
		super(param);
		this.param = param;
	}

	@Override
	public boolean getUpdateRequired() {
		return this.param.getUpdateRequired();
	}

	@Override
	public boolean getUpdateRequired(int index) {
		return this.param.getUpdateRequired(index);
	}

	@Override
	public void setUpdateRequired(boolean update) {
		this.param.setUpdateRequired(update);
	}

	@Override
	public void setUpdateRequired(int index, boolean update) {
		this.param.setUpdateRequired(index, update);
	}

	@Override
	public IDepend getDepend() throws RemoteException {
		return this.param.getDepend().getRMIImpl();
	}

	@Override
	public void reset() {
		this.param.reset();
	}

	@Override
	public int update(Map<String, Object> args) throws Exception {
		return this.param.update(args);
	}

	@Override
	public void refreshDepend(boolean dirty, boolean load) {
		this.param.refreshDepend(dirty, load);
	}

	@Override
	public void refreshDependency() {
		this.param.refreshDependency();
	}

	@Override
	public CParamCollector getClientImpl() {
		return new CParamCollector(this);
	}
}
