/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9752 $
 * $Date: 2020-04-11 00:01:35 +0200 (Sat, 11 Apr 2020) $
 */
package at.lcm.bu21.magopt.structure.rmi;

import java.rmi.RemoteException;

import at.lcm.bu21.general.dtypes.TData;
import at.lcm.bu21.general.dtypes.unit.ConversionException;
import at.lcm.bu21.magopt.structure.IParamField;
import at.lcm.bu21.magopt.structure.ParamField;
import at.lcm.bu21.magopt.structure.ParamFormula;
import at.lcm.bu21.magopt.structure.ParamLinkedField;
import at.lcm.bu21.magopt.structure.client.CParamField;

/**
 * RMI adapter for field
 * 
 * @author Werner Koppelsttter
 */
public class RParamField extends RParameter implements IParamField {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Field class */
	private ParamField param;

	/**
	 * Create rmi adapter for field
	 * 
	 * @param param
	 *            Field
	 * @throws RemoteException
	 */
	public RParamField(ParamField param) throws RemoteException {
		super(param);
		this.param = param;
	}

	@Override
	public String getTexString() throws RemoteException {
		return this.param.getTexString();
	}

	@Override
	public void setTexString(String texString) {
		this.param.setTexString(texString);

	}

	@Override
	public String getUnit() {
		return this.param.getUnit();
	}

	@Override
	public void setUnit(String unit) throws Exception {
		this.param.setUnit(unit);
	}

	@Override
	public void setUnit(String unit, boolean convert) throws Exception {
		this.param.setUnit(unit, convert);
	}

	@Override
	public String getType() {
		return this.param.getType();
	}

	@Override
	public void setType(String type) {
		this.param.setType(type);

	}

	@Override
	public long getDbId() {
		return this.param.getDbId();
	}

	@Override
	public void clearDbId() {
		this.param.clearDbId();
	}

	@Override
	public boolean getLock() {
		return this.param.getLock();
	}

	@Override
	public ParamField convertToParamField() {
		return this.param.convertToParamField();
	}

	@Override
	public ParamField convertToParamComboBox() {
		return this.param.convertToParamComboBox();
	}

	@Override
	public ParamFormula convertToParamFormula() {
		return this.param.convertToParamFormula();
	}

	@Override
	public ParamLinkedField convertToParamLinkedField() {
		return this.param.convertToParamLinkedField();
	}

	@Override
	public TData getData(String unit) throws RemoteException, ConversionException {
		return this.param.getData(unit);
	}

	@Override
	public TData getData(int index, String unit) throws RemoteException, ConversionException {
		return this.param.getData(index, unit);
	}

	@Override
	public void setData(TData data, String unit) throws RemoteException, ConversionException, Exception {
		this.param.setData(data, unit);
	}

	@Override
	public CParamField getClientImpl() {
		return new CParamField(this);
	}
}
