/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.rmi;

import java.io.File;
import java.rmi.RemoteException;

import at.lcm.bu21.magopt.structure.IParamFile;
import at.lcm.bu21.magopt.structure.ParamFile;
import at.lcm.bu21.magopt.structure.client.CParamFile;

/**
 * RMI adapter for file
 * 
 * @author Werner Koppelsttter
 */
public class RParamFile extends RParamDirectory implements IParamFile {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** File class */
	private ParamFile param;

	/**
	 * Create rmi adapter for file
	 * 
	 * @param param
	 *            File
	 * @throws RemoteException
	 */
	public RParamFile(ParamFile param) throws RemoteException {
		super(param);
		this.param = param;
	}

	@Override
	public String getFileName() {
		return this.param.getFileName();
	}

	@Override
	public void setFileName(String name) {
		this.param.setFileName(name);
	}

	@Override
	public File getAbsoluteFile() {
		return this.param.getAbsoluteFile();
	}

	@Override
	public void setAbsoluteFile(File file) {
		this.param.setAbsoluteFile(file);
	}

	@Override
	public CParamFile getClientImpl() {
		return new CParamFile(this);
	}
}
