/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.compare;

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.JTextField;
import javax.swing.LayoutStyle.ComponentPlacement;
import javax.swing.SpinnerNumberModel;
import javax.swing.WindowConstants;
import javax.swing.border.EmptyBorder;
import javax.swing.border.TitledBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.filechooser.FileFilter;
import javax.swing.filechooser.FileNameExtensionFilter;

import at.lcm.bu21.magopt.structure.Project;
import at.lcm.bu21.magopt.structure.compare.CompareParameter;

/**
 * Dialog to select project and index to compare
 * 
 * @author Werner Koppelsttter
 */
public class CompareProject extends JDialog {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Project number 1 */
	private Project proj1 = null;

	/** Project number 2 */
	private Project proj2 = null;

	/** Index of project number 1 */
	private int index1 = 0;

	/** Index of project number 2 */
	private int index2 = 0;

	/** Field with file of project 1 */
	private JTextField projField1;

	/** Field with file of project 2 */
	private JTextField projField2;

	/** Spinner with index of project 1 */
	private JSpinner indexSpinner1;

	/** Spinner with index of project 2 */
	private JSpinner indexSpinner2;

	/** Spinner model for index of project 1 */
	private SpinnerNumberModel indexModel1;

	/** Spinner model for index of project 2 */
	private SpinnerNumberModel indexModel2;

	/** Compare results */
	private JCheckBox chckbxCompareResults;

	/** Button to compare */
	JButton compare;

	/** File-filter for mopt-files */
	FileFilter moptFilter = new FileNameExtensionFilter(
			"MagOpt Template Files (*.mopt)", "mopt");

	/** File-filter for mop-files */
	FileFilter mopFilter = new FileNameExtensionFilter(
			"MagOpt Project Files (*.mop)", "mop");

	/**
	 * Select project to compare
	 * 
	 * @param proj
	 *            Initial project
	 */
	public CompareProject(Project proj) {
		JPanel panelSelection, panelSource1, panelSource2, panelSettings, panelButton;
		JLabel labelProject1, labelIndex1, labelProject2, labelIndex2;
		JButton select1, select2;

		this.proj1 = proj;
		this.index1 = 1;
		if (this.proj1 != null) {
			this.index1 = this.proj1.getIndex();
		}
		this.proj2 = this.proj1;
		this.index2 = this.index1;

		// init project 1
		labelProject1 = new JLabel("Project");
		this.projField1 = new JTextField();
		this.projField1.setEditable(false);
		select1 = new JButton("...");
		select1.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent event) {
				JFileChooser chooser;
				int returnVal;

				chooser = new JFileChooser();
				if (CompareProject.this.proj1 != null) {
					chooser.setCurrentDirectory(CompareProject.this.proj1
							.getMopFile());
				}
				chooser.setFileFilter(CompareProject.this.moptFilter);
				chooser.setFileFilter(CompareProject.this.mopFilter);

				returnVal = chooser.showOpenDialog(CompareProject.this);
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					try {
						CompareProject.this.proj1 = Project.load(chooser
								.getSelectedFile().getAbsolutePath());
						CompareProject.this.index1 = CompareProject.this.proj1
								.getIndex();
					} catch (Exception e) {
					}
				}
				CompareProject.this.refresh();
			}
		});
		labelIndex1 = new JLabel("Index");
		this.indexModel1 = new SpinnerNumberModel(1, 1, 1, 1);
		this.indexModel1.addChangeListener(new ChangeListener() {
			@Override
			public void stateChanged(ChangeEvent event) {
				CompareProject.this.index1 = ((Integer) CompareProject.this.indexModel1
						.getValue()) - 1;
			}
		});
		this.indexSpinner1 = new JSpinner(this.indexModel1);

		// init project 2
		labelProject2 = new JLabel("Project");
		this.projField2 = new JTextField();
		this.projField2.setEditable(false);
		// this.projField2.setColumns(10);
		select2 = new JButton("...");
		select2.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent event) {
				JFileChooser chooser;
				int returnVal;

				chooser = new JFileChooser();
				if (CompareProject.this.proj2 != null) {
					chooser.setCurrentDirectory(CompareProject.this.proj2
							.getMopFile());
				}
				chooser.setFileFilter(CompareProject.this.moptFilter);
				chooser.setFileFilter(CompareProject.this.mopFilter);

				returnVal = chooser.showOpenDialog(CompareProject.this);
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					try {
						CompareProject.this.proj2 = Project.load(chooser
								.getSelectedFile().getAbsolutePath());
						CompareProject.this.index2 = CompareProject.this.proj2
								.getIndex();
					} catch (Exception e) {
					}
				}
				CompareProject.this.refresh();
			}
		});
		labelIndex2 = new JLabel("Index");
		this.indexModel2 = new SpinnerNumberModel(1, 1, 1, 1);
		this.indexModel2.addChangeListener(new ChangeListener() {
			@Override
			public void stateChanged(ChangeEvent event) {
				CompareProject.this.index2 = ((Integer) CompareProject.this.indexModel2
						.getValue()) - 1;
			}
		});
		this.indexSpinner2 = new JSpinner(this.indexModel2);

		// init dialog layout
		this.setTitle("Compare project");
		this.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		this.getContentPane().setLayout(new BorderLayout());
		panelSelection = new JPanel();
		panelSelection.setBorder(new EmptyBorder(5, 5, 5, 5));
		this.getContentPane().add(panelSelection, BorderLayout.CENTER);
		panelSelection.setLayout(new GridLayout(0, 1, 0, 0));

		// souce 1
		panelSource1 = new JPanel();
		panelSource1.setBorder(new TitledBorder(null, "Source 1",
				TitledBorder.LEADING, TitledBorder.TOP, null, null));
		panelSelection.add(panelSource1);

		GroupLayout gl_panelSource1 = new GroupLayout(panelSource1);
		gl_panelSource1
				.setHorizontalGroup(gl_panelSource1
						.createParallelGroup(Alignment.LEADING)
						.addGroup(
								gl_panelSource1
										.createSequentialGroup()
										.addContainerGap()
										.addGroup(
												gl_panelSource1
														.createParallelGroup(
																Alignment.LEADING)
														.addComponent(
																labelProject1)
														.addComponent(
																labelIndex1))
										.addGap(18)
										.addGroup(
												gl_panelSource1
														.createParallelGroup(
																Alignment.LEADING)
														.addGroup(
																gl_panelSource1
																		.createSequentialGroup()
																		.addComponent(
																				this.projField1,
																				GroupLayout.DEFAULT_SIZE,
																				639,
																				Short.MAX_VALUE)
																		.addPreferredGap(
																				ComponentPlacement.RELATED)
																		.addComponent(
																				select1))
														.addComponent(
																this.indexSpinner1,
																GroupLayout.PREFERRED_SIZE,
																80,
																GroupLayout.PREFERRED_SIZE))
										.addContainerGap()));
		gl_panelSource1
				.setVerticalGroup(gl_panelSource1
						.createParallelGroup(Alignment.LEADING)
						.addGroup(
								gl_panelSource1
										.createSequentialGroup()
										.addGroup(
												gl_panelSource1
														.createParallelGroup(
																Alignment.BASELINE)
														.addComponent(
																labelProject1)
														.addComponent(
																this.projField1,
																GroupLayout.PREFERRED_SIZE,
																GroupLayout.DEFAULT_SIZE,
																GroupLayout.PREFERRED_SIZE)
														.addComponent(select1))
										.addPreferredGap(
												ComponentPlacement.UNRELATED)
										.addGroup(
												gl_panelSource1
														.createParallelGroup(
																Alignment.BASELINE)
														.addComponent(
																labelIndex1)
														.addComponent(
																this.indexSpinner1,
																GroupLayout.PREFERRED_SIZE,
																GroupLayout.DEFAULT_SIZE,
																GroupLayout.PREFERRED_SIZE))
										.addContainerGap(33, Short.MAX_VALUE)));
		panelSource1.setLayout(gl_panelSource1);

		// source 2
		panelSource2 = new JPanel();
		panelSource2.setBorder(new TitledBorder(null, "Source 2",
				TitledBorder.LEADING, TitledBorder.TOP, null, null));
		panelSelection.add(panelSource2);

		GroupLayout gl_panelSource2 = new GroupLayout(panelSource2);
		gl_panelSource2
				.setHorizontalGroup(gl_panelSource2
						.createParallelGroup(Alignment.LEADING)
						.addGroup(
								gl_panelSource2
										.createSequentialGroup()
										.addContainerGap()
										.addGroup(
												gl_panelSource2
														.createParallelGroup(
																Alignment.LEADING)
														.addComponent(
																labelProject2)
														.addComponent(
																labelIndex2))
										.addGap(18)
										.addGroup(
												gl_panelSource2
														.createParallelGroup(
																Alignment.LEADING)
														.addGroup(
																gl_panelSource2
																		.createSequentialGroup()
																		.addComponent(
																				this.projField2,
																				GroupLayout.DEFAULT_SIZE,
																				639,
																				Short.MAX_VALUE)
																		.addPreferredGap(
																				ComponentPlacement.RELATED)
																		.addComponent(
																				select2))
														.addComponent(
																this.indexSpinner2,
																GroupLayout.PREFERRED_SIZE,
																80,
																GroupLayout.PREFERRED_SIZE))
										.addContainerGap()));
		gl_panelSource2
				.setVerticalGroup(gl_panelSource2
						.createParallelGroup(Alignment.LEADING)
						.addGroup(
								gl_panelSource2
										.createSequentialGroup()
										.addGroup(
												gl_panelSource2
														.createParallelGroup(
																Alignment.BASELINE)
														.addComponent(
																labelProject2)
														.addComponent(
																this.projField2,
																GroupLayout.PREFERRED_SIZE,
																GroupLayout.DEFAULT_SIZE,
																GroupLayout.PREFERRED_SIZE)
														.addComponent(select2))
										.addPreferredGap(
												ComponentPlacement.UNRELATED)
										.addGroup(
												gl_panelSource2
														.createParallelGroup(
																Alignment.BASELINE)
														.addComponent(
																labelIndex2)
														.addComponent(
																this.indexSpinner2,
																GroupLayout.PREFERRED_SIZE,
																GroupLayout.DEFAULT_SIZE,
																GroupLayout.PREFERRED_SIZE))
										.addContainerGap(33, Short.MAX_VALUE)));
		panelSource2.setLayout(gl_panelSource2);

		// settings
		panelSettings = new JPanel();
		panelSettings.setBorder(new TitledBorder(null, "Settings",
				TitledBorder.LEADING, TitledBorder.TOP, null, null));
		panelSelection.add(panelSettings);
		panelSettings.setLayout(new GridLayout(0, 1, 0, 0));

		this.chckbxCompareResults = new JCheckBox("Compare results");
		panelSettings.add(this.chckbxCompareResults);

		// button
		panelButton = new JPanel();
		panelButton.setBorder(new EmptyBorder(0, 5, 5, 5));
		this.getContentPane().add(panelButton, BorderLayout.SOUTH);
		panelButton.setLayout(new BorderLayout(0, 0));

		this.compare = new JButton("Compare");
		this.compare.setEnabled(false);
		this.compare.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent event) {
				CompareParameter comp;
				CompareProject.this.setVisible(false);
				comp = new CompareParameter();
				comp.compare(CompareProject.this.proj1,
						CompareProject.this.index1, CompareProject.this.proj2,
						CompareProject.this.index2,
						CompareProject.this.chckbxCompareResults.isSelected());
				new CompareDialog(comp);
				CompareProject.this.dispose();

			}
		});
		panelButton.add(this.compare, BorderLayout.NORTH);

		this.refresh();

		this.setSize(600, 350);
		this.setLocationByPlatform(true);
		this.setVisible(true);

	}

	/**
	 * Refresh display content
	 */
	public void refresh() {

		// project 1
		if (this.proj1 == null) {
			this.projField1.setText("");
			this.index1 = 0;
			this.indexModel1.setValue(1);
			this.indexModel1.setMaximum(1);
		} else {
			this.projField1.setText(this.proj1.getMopFile().toString());
			this.indexModel1.setValue(this.index1 + 1);
			this.indexModel1.setMaximum(this.proj1.getLength());
		}
		this.indexSpinner1.setEnabled(this.proj1 != null);

		// project 2
		if (this.proj2 == null) {
			this.projField2.setText("");
			this.index2 = 0;
			this.indexModel2.setValue(1);
			this.indexModel2.setMaximum(1);
		} else {
			this.projField2.setText(this.proj2.getMopFile().toString());
			this.indexModel2.setValue(this.index2 + 1);
			this.indexModel2.setMaximum(this.proj2.getLength());
		}
		this.indexSpinner2.setEnabled(this.proj2 != null);

		// compare button
		this.compare.setEnabled((this.proj1 != null) && (this.proj2 != null));
	}
}
