/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.event;

import java.awt.Color;
import java.awt.Component;

import javax.swing.ImageIcon;
import javax.swing.JTable;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.table.DefaultTableCellRenderer;

import magopt.gui.icons.IconEvent;
import at.lcm.bu21.magopt.structure.event.Event;

/**
 * Cell-renderer for event-list
 * 
 * @author Werner Koppelsttter
 */
public class EventRenderer extends DefaultTableCellRenderer {
	/** Serialization version number */
	private static final long serialVersionUID = 1L;
	/** Color for info event */
	final static Color COLOR_INFO = Color.BLACK;
	/** Color for warning event */
	final static Color COLOR_WARNING = Color.BLUE;
	/** Color for error event */
	final static Color COLOR_ERROR = Color.RED;
	/** Color for selected item */
	final static Color COLOR_SELECTED = Color.LIGHT_GRAY;
	/** Default border */
	private final static Border BORDER = new EmptyBorder(0, 5, 0, 5);

	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		Event event;
		ImageIcon icon;

		event = (Event) table.getModel().getValueAt(row, column);

		// dedect type of event
		switch (event.getType()) {
		case WARNING:
			this.setForeground(EventRenderer.COLOR_WARNING);
			icon = IconEvent.ICON_WARNING;
			break;
		case ERROR:
			this.setForeground(EventRenderer.COLOR_ERROR);
			icon = IconEvent.ICON_ERROR;
			break;
		default:
			this.setForeground(EventRenderer.COLOR_INFO);
			icon = IconEvent.ICON_INFO;
			break;
		}

		// mark selected
		if (isSelected) {
			this.setBackground(EventRenderer.COLOR_SELECTED);
		} else {
			this.setBackground(null);
		}

		// display cell-content
		if (column == EventColumn.TYPE.getValue()) {
			this.setIcon(icon);
			this.setText(null);
		} else if (column == EventColumn.DATE.getValue()) {
			this.setIcon(null);
			this.setText(event.getDateString());
		} else if (column == EventColumn.DESCRIPTION.getValue()) {
			this.setIcon(null);
			this.setText(event.getDescription().replace("\n", "; "));
		} else {
			this.setIcon(null);
			this.setText(null);
		}

		this.setToolTipText("<html>"
				+ event.getDescription().replace("\n", "<br>") + "</html>");
		this.setBorder(EventRenderer.BORDER);

		return this;
	}
}
