/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.docfiles;

/**
 * Connects Column Indices with Column Header Names.
 * 
 * @author Werner Koppelsttter
 */
public enum DocFilesColumn {
	/** Icon of DocFile */
	ICON(0, "Icon"),
	/** Name of DocFile */
	NAME(1, "Name"),
	/** Description of DocFile */
	DESCRIPTION(2, "Description"),
	/** CheckSum valid */
	CHECKSUM(3, "Valid");

	/** Column number */
	private final int column;
	/** Column name */
	private final String name;

	/**
	 * Create enumeration
	 * 
	 * @param column
	 *            Column number
	 * @param name
	 *            Column name
	 */
	private DocFilesColumn(int column, String name) {
		this.column = column;
		this.name = name;
	}

	/**
	 * Get column number
	 * 
	 * @return Number
	 */
	int getValue() {
		return this.column;
	}

	/**
	 * Get column name
	 * 
	 * @return Name
	 */
	String getName() {
		return this.name;
	}

}
