/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.web;

import java.awt.BorderLayout;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import javax.swing.JPanel;

import org.cef.CefApp;
import org.cef.CefClient;
import org.cef.CefSettings;
import org.cef.OS;
import org.cef.browser.CefBrowser;

/**
 * Panel to display web-content
 *
 * @author Werner Koppelsttter
 */
// public class WebPanel extends JFXPanel {
// FX browser
public class WebPanel extends JPanel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** cef-client */
	private static CefClient client = null;

	/** cef-browser */
	CefBrowser browser = null;

	/** Current loading thread */
	private Thread currentThread = null;

	// FX browser
	// /** Browser */
	// private WebView browser;

	// FX browser
	// /** Browser engine */
	// private WebEngine engine;

	/**
	 * Create WebPanel
	 */
	public WebPanel() {

		// FX browser
		// PlatformImpl.runLater(new Runnable() {
		// @Override
		// public void run() {
		// Stage stage;
		// Group group;
		// Scene scene;
		// ObservableList<Node> children;
		// Dimension dim;
		//
		// stage = new Stage();
		//
		// stage.setTitle("Component browser");
		// stage.setResizable(true);
		//
		// group = new Group();
		//
		// scene = new Scene(group);
		// // scene = new Scene(group, 80, 20);
		// stage.setScene(scene);
		//
		// WebPanel.this.browser = new WebView();
		// WebPanel.this.engine = WebPanel.this.browser.getEngine();
		//
		// children = group.getChildren();
		// children.add(WebPanel.this.browser);
		//
		// WebPanel.this.setScene(scene);
		//
		// dim = WebPanel.this.getSize();
		// WebPanel.this.browser.setPrefSize(dim.getWidth(),
		// dim.getHeight());
		// }
		// });
		//
		// // resize panel
		// this.addComponentListener(new ComponentAdapter() {
		// @Override
		// public void componentResized(ComponentEvent e) {
		// Dimension dim;
		//
		// if (WebPanel.this.browser != null) {
		// dim = WebPanel.this.getSize();
		// WebPanel.this.browser.setPrefSize(dim.getWidth(),
		// dim.getHeight());
		// }
		// }
		// });

		if (WebPanel.client == null) {
			try {
				CefSettings settings = new CefSettings();
				settings.windowless_rendering_enabled = OS.isLinux();
				CefApp app = CefApp.getInstance(
						// new String[] { "--ignore-gpu-blacklist",
						// "--enable-webgl", "--enable_gpu" },
						settings);

				// load Browser
				WebPanel.client = CefApp.getInstance().createClient();
				WebPanel.client.addContextMenuHandler(new ContextMenuHandler());
			} catch (Throwable e) {
				System.err.println("Unable to use browser");
				System.err.println(e.getMessage());
				e.printStackTrace();
			}
		}

		if (WebPanel.client != null) {
			this.browser = WebPanel.client.createBrowser("", OS.isLinux(), false);
			this.setLayout(new BorderLayout());
			this.add(this.browser.getUIComponent(), BorderLayout.CENTER);
		}
	}

	/**
	 * Load url in browser
	 * 
	 * @param url
	 *            Url of content
	 */
	public void load(final String url) {
		// FX browser
		// PlatformImpl.runLater(new Runnable() {
		// @Override
		// public void run() {
		// WebPanel.this.engine.load(url);
		// }
		// });

		this.currentThread = new Thread() {
			@Override
			public void run() {
				String oldUrl;
				int cnt = 0;

				if (WebPanel.this.browser != null) {
					// stop loader of old site
					if (WebPanel.this.browser.isLoading()) {
						WebPanel.this.browser.stopLoad();
					}

					oldUrl = WebPanel.this.browser.getURL();
					if (!oldUrl.equals(url)) {
						// load until site changed
						do {
							if (!WebPanel.this.browser.isLoading()) {
								WebPanel.this.browser.loadURL(url);
								cnt++;
							}

							try {
								Thread.sleep(100);
							} catch (InterruptedException e) {
								System.err.println(e.getMessage());
								e.printStackTrace();
							}
						} while ((Thread.currentThread() == Thread.currentThread())
								&& oldUrl.equals(WebPanel.this.browser.getURL()) && (cnt < 100));
					}
				}
			}
		};
		this.currentThread.start();
	}

	/**
	 * Load content in browser
	 * 
	 * @param content
	 *            Html of content
	 */
	public void loadContent(final String content) {
		// FX browser
		// PlatformImpl.runLater(new Runnable() {
		// @Override
		// public void run() {
		// WebPanel.this.engine.loadContent(content);
		// }
		// });

		new Thread() {
			@Override
			public void run() {
				String url = "";
				File file, dir;
				BufferedWriter w;

				// get new html file
				dir = new File(System.getenv("Temp"), "SyMSpaceBrowser");
				dir.mkdirs();
				int uniqueDirName = 0;
				do {
					file = new File(dir, "html_" + uniqueDirName++ + ".html");
				} while (file.exists());

				// write conten to file
				try {
					w = new BufferedWriter(new FileWriter(file));
					w.write(content);
					w.close();
					file.deleteOnExit();
					url = file.toURI().toURL().toString();
				} catch (IOException e) {
					System.err.println(e.getMessage());
					e.printStackTrace();
				}

				// load file
				WebPanel.this.load(url);
			}
		}.start();

	}

}
