/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.structure.database;

import java.util.LinkedList;

import at.lcm.bu21.magopt.structure.event.EventLog;

/**
 * Manager the connections to material-database
 * 
 * @author Werner Koppelsttter
 */
public interface MaterialConnection {

	/**
	 * Get array of database-items of current material. First item for
	 * material-class, second item for material and the last item for dataset
	 * 
	 * @param datasetID
	 *            ID of dataset
	 * 
	 * @return List of dataset-items
	 */
	public DBItem[] getMaterialItems(long datasetID);

	/**
	 * Get list of material-classes
	 * 
	 * @return list of material-classes items
	 */
	public DBItem[] getMaterialClassList();

	/**
	 * Get list of materials
	 * 
	 * @param materialClass
	 *            Item of material-class for filter
	 * @return list of materials
	 */
	public DBItem[] getMaterialList(DBItem materialClass);

	/**
	 * Get list of materials
	 * 
	 * @param material
	 *            Item of material for filter
	 * @return list of materials
	 */
	public DBItem[] getDatasetList(DBItem material);

	/**
	 * Get list of properties from a wanted material
	 * 
	 * @param datasetID
	 *            ID of dataset
	 * @param log
	 *            Log for error-message
	 * @return Material-properties
	 */
	public LinkedList<MaterialProperty<Double>> getProperties(long datasetID,
			EventLog log);

	/**
	 * Get list of diagrams from a wanted material
	 * 
	 * @param datasetID
	 *            ID of dataset
	 * @param log
	 *            Log for error-message
	 * @return Material-diagrams
	 */
	public LinkedList<MaterialDiagram> getDiagrams(long datasetID, EventLog log);

	/**
	 * Close connection to material
	 */
	public void close();

}
