/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.utils;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import at.lcm.bu21.general.utils.FileUtils;
import at.lcm.bu21.magopt.structure.Project;

/**
 * HtmlWriter for writing html-reports
 * 
 * @author Werner Koppelsttter
 */
public class HtmlWriter {

	/**
	 * Content of the file
	 */
	protected StringBuffer content = new StringBuffer();

	/**
	 * Directory where the html-file should write
	 */
	protected File directory;

	/**
	 * Create HtmlWriter for given directory
	 * 
	 * @param directory
	 *            directory for writer
	 */
	public HtmlWriter(String directory) {
		this(new File(directory));
	}

	/**
	 * Create HtmlWriter for given directory
	 * 
	 * @param directory
	 *            directory for writer
	 */
	public HtmlWriter(File directory) {
		this.directory = directory;
	}

	/**
	 * Add string to content
	 * 
	 * @param str
	 *            String to add
	 */
	public void add(String str) {
		this.content.append(str);
	}

	/**
	 * Add content of HtmlWriter to content
	 * 
	 * @param report
	 *            HtmlWriter to add
	 */
	public void addWriter(HtmlWriter report) {
		this.content.append(report.content);
	}

	/**
	 * Get directory-string of the report for paths or files
	 * 
	 * @return directory-string
	 */
	public String getDirectory() {
		return this.directory.getPath();
	}

	/**
	 * Get directory of the report for paths or files
	 * 
	 * @return Directory
	 */
	public File getDirectoryFile() {
		return this.directory;
	}

	/**
	 * Write content to html-file
	 * 
	 * @throws IOException
	 */
	public void write() throws IOException {
		File file, css;
		FileWriter fw;

		this.directory.mkdirs();
		file = new File(this.directory, "index.html");
		css = new File(this.directory.getPath(), "LibContents_ACCM.css");
		fw = new FileWriter(file);

		// copy style-sheet
		if (css.exists()) {
			css.delete();
		}
		FileUtils.copy(new File(Project.getLibraryPath()
				+ "\\Utils\\css\\LibContents_ACCM.css"), css);

		// write report
		fw.write(this.content.toString());
		fw.close();
	}

}
