/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 257 $
 * $Date: 2021-04-10 17:30:11 +0200 (Sat, 10 Apr 2021) $
 */
package at.lcm.bu21.optim.core.plot;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;

import org.json.simple.JSONObject;

import at.lcm.bu21.general.utils.Pair;
import at.lcm.bu21.magopt.structure.ParamField;
import at.lcm.bu21.magopt.structure.Project;
import at.lcm.bu21.optim.core.Individual;
import at.lcm.bu21.optim.core.ObjectiveType;
import at.lcm.bu21.optim.core.Problem;
import at.lcm.bu21.optim.core.ResultDesc;
import at.lcm.bu21.optim.core.VariableDesc;

public class PlotJson {

	public enum ResultType {
		OBJECTIVES, CONSTAINTS, RESULTS;
	}

	public static String getJsonString(Problem prob, boolean variables, ResultType results) {
		// list of used variables and results
		ArrayList<Pair<String, String>> vars;
		ArrayList<Pair<String, String>> ress;
		// data-structure for json
		HashMap<String, Object> obj;
		ArrayList<Object> tablesList;
		HashMap<String, Object> tables;
		ArrayList<Object> list;
		HashMap<String, Object> table;
		// auxiliary variables
		ObjectiveType type;
		String name;
		int index;
		Project proj;
		ParamField field;

		obj = new HashMap<String, Object>();
		tablesList = new ArrayList<Object>();
		obj.put("tables", tablesList);

		tables = new HashMap<String, Object>();
		tablesList.add(tables);

		tables.put("name", prob.getArchive().getName() + ":" + prob.getName());
		list = new ArrayList<Object>();
		tables.put("columns", list);

		// ID description
		table = new HashMap<String, Object>();
		table.put("name", "ID");
		list.add(table);

		vars = new ArrayList<Pair<String, String>>();
		ress = new ArrayList<Pair<String, String>>();

		proj = prob.getArchive().getProject();

		// result description
		for (ResultDesc res : prob.getResults()) {
			type = res.getObjective();
			if ((results == ResultType.RESULTS)
					|| ((results == ResultType.CONSTAINTS) && ((type != ObjectiveType.NONE) || (res.isConstraint())))
					|| ((results == ResultType.OBJECTIVES) && (type != ObjectiveType.NONE))) {
				table = new HashMap<String, Object>();
				list.add(table);

				field = (ParamField) proj.getObject(res.getName());
				name = field.getShortIdentifier();
				name += " / " + field.getUnit();
				name += " (" + res.getObjective().name() + ")";

				ress.add(new Pair<String, String>(name, res.getName()));
				table.put("name", name);
				table.put("obj", type.name());
			}
		}
		// variable description
		if (variables) {
			for (VariableDesc var : prob.getVariables()) {
				table = new HashMap<String, Object>();
				list.add(table);

				field = (ParamField) proj.getObject(var.getName());
				name = field.getShortIdentifier();
				name += " / " + field.getUnit();

				vars.add(new Pair<String, String>(name, var.getName()));
				table.put("name", name);
			}
		}

		// write values of pareto-front
		list = new ArrayList<Object>();
		tables.put("rows", list);
		index = prob.getNumSavePoints() - 1;
		if (index >= 0) {
			for (Individual ind : prob.getSavePoint(index).getFullPareto()) {
				table = new HashMap<String, Object>();
				list.add(table);
				// ID of individual
				table.put("ID", prob.getArchive().getMemory().getIndexOf(ind));
				// results
				for (Pair<String, String> p : ress) {
					table.put(p.getFirst(), ind.getResult(p.getSecond()));
				}
				// variables
				for (Pair<String, String> p : vars) {
					table.put(p.getFirst(), ind.getVariable(p.getSecond()));
				}
			}
		}

		return JSONObject.toJSONString(obj);
	}

	public static void exportJson(Problem prob, boolean variables, ResultType results, File json) throws IOException {
		FileWriter out;

		out = new FileWriter(json);
		out.write(PlotJson.getJsonString(prob, variables, results));
		out.close();
	}
}
