# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10062 $
$LastChangedDate:: 2020-11-20 13:22:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
from symspace.console.script_utils import ScriptUtils
from symspace.generic_gui_qt import GUIFormThread
from symspace.wrapper.symoptutils import SyMOptUtils
from symspace.wrapper.symoptwrapper import SymArchive


def main():
    project_list = ScriptUtils.selectProjects(n_projects=2)
    if len(tuple(project_list)) == 2:
        prj_file_1 = project_list[0].getFile(get_abs_path=True)
        prj_file_2 = project_list[1].getFile(get_abs_path=True)

        archive_list_1 = SymArchive.listArchives(prj_file_1)
        archive_list_2 = SymArchive.listArchives(prj_file_2)
    
        if len(archive_list_1) == 0:
            raise Exception('The selected project 1 does not contain optimization archives!')
        if len(archive_list_2) == 0:
            raise Exception('The selected project 2 does not contain optimization archives!')

        form_title = 'Merge Archives'
        form_elements = [
            ('Project 1', 'label', prj_file_1),
            ('Archive Name 1', 'combobox', archive_list_1),
            ('Project 2', 'label', prj_file_2),
            ('Archive Name 2', 'combobox', archive_list_2),
            ('Project Merged', 'label', prj_file_1),
            ('Archive Name Merged', 'line', 'a_merged'),
        ]
        form = GUIFormThread(form_title, form_elements)

        form.start()
        if form.accept:
            archive_name_1 = form.result['Archive Name 1']
            archive_name_2 = form.result['Archive Name 2']
            archive_name_merged = form.result['Archive Name Merged']
            archives = [SymArchive.load(prj_file_1, archive_name_1),
                        SymArchive.load(prj_file_2, archive_name_2)]
            SyMOptUtils.mergeArchives(archives, archive_name_merged)

            print('Update finished')
        else:
            print('Cancelled by user')


if __name__ == '__main__':
    """
    This script merges two compatible optimization archives

    This script needs to be executed in the SyMSpace-Optimizer Python Console.
    """

    ScriptUtils.run(main)

