#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10062 $
$LastChangedDate:: 2020-11-20 13:22:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
from symspace.wrapper.symoptwrapper import SymArchive, SymProblem
from symspace.console.script_utils import ScriptUtils
from symspace.generic_gui_qt import GUIFormThread


def printNumProjectIndividuals(prj_file: str):
    """use all existing archive names of this project"""
    archive_names = SymArchive.listArchives(prj_file)

    for index, a_name in enumerate(archive_names):
        '''loop over archive names'''
        archive = SymArchive.load(prj_file, a_name)
        memory = archive.getMemory()
        n_ind = memory.getNumIndividuals()
        print('{} - Number of individuals: {}'.format(a_name, n_ind))

        '''use all existing problem names of this archive'''
        problem_names = archive.listProblems()

        for p_name in problem_names:
            '''loop over problem names'''
            problem = archive.readProblem(p_name)
            n_val_ind = len(memory.getValidIndividuals(problem))
            print('{} {} - Number of valid individuals: {}'.format(a_name, p_name, n_val_ind))


def printProblemNumIndividuals(problem: SymProblem):
    p_name = problem.getName()
    archive = problem.getArchive()
    a_name = archive.getName()
    memory = archive.getMemory()
    n_ind = memory.getNumIndividuals()
    n_ind_vd = len(memory.getValidIndividuals(problem))
    print('{} - Number of individuals: {}'.format(a_name, n_ind))
    print('{} {} - Number of valid individuals: {}'.format(a_name, p_name, n_ind_vd))


def main(params: dict):
    project = ScriptUtils.selectProjectFromParams(params)
    if project is not None:
        prj_file = project.getFile(get_abs_path=True)

        archive_problem_list = ScriptUtils.getProblemsList(prj_file)
        archive_problem_list.append('all')

        form_title = 'Print Number of Individuals'
        form_elements = [
            ('Archive//Problem Name', 'combobox', archive_problem_list),
        ]
        form = GUIFormThread(form_title, form_elements)

        form.start()
        if form.accept:
            archive_problem = form.result['Archive//Problem Name']

            if archive_problem == 'all':
                printNumProjectIndividuals(prj_file)
            else:
                archive_name, problem_name = ScriptUtils.parseArchiveProblemName(archive_problem)

                archive = SymArchive.load(prj_file, archive_name)
                problem = archive.readProblem(problem_name)
                printProblemNumIndividuals(problem)
            print('Update finished')
        else:
            print('Cancelled by user')


if __name__ == '__main__':
    """
    This script prints the number of individuals of the selected optimization archive(s) and problem(s)

    This script needs to be executed in the SyMSpace Python Console.
    """
    _params = locals()
    ScriptUtils.run(main, _params)


