# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10062 $
$LastChangedDate:: 2020-11-20 13:22:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
from symspace.console.script_utils import ScriptUtils
from symspace.wrapper.symwrapper import SymProject, SymParameter
from symspace.generic_gui_qt import GUIFormThread


def main(project: SymProject, parameter: SymParameter):
    options = ['regenerate', 'reset', 'generate DocFiles', 'delete DocFiles']
    form_title = 'Select action to perform'
    form_elements = [
        ('Task', 'combobox', options),
        ('Simulation Settings:', 'label'),
        ('\tStart Simulation', 'checkbox', False),
        ('\tRemote Compute', 'checkbox', False),
        ('\tOptimize', 'checkbox', False),
        ('Additional options:', 'label'),
        ('\tOnly for selected parameter', 'checkbox', False)
    ]

    form = GUIFormThread(form_title, form_elements)

    form.start()

    if form.accept:
        task = form.result['Task']
        only_selected = form.result['\tOnly for selected parameter']

        run_args = dict(RunSim=False, RemoteCompute=False, Optimize=False)
        run_args['RunSim'] = form.result['\tStart Simulation']
        run_args['RemoteCompute'] = form.result['\tRemote Compute']
        run_args['Optimize'] = form.result['\tOptimize']

        cur_index = project.getIndex()
        for idx in range(project.getLength()):
            project.setIndex(idx)
            if task == 'reset':
                if only_selected and hasattr(parameter, 'reset'):
                    parameter.reset()
                elif only_selected and not hasattr(parameter, 'reset'):
                    raise Exception('Current parameter has no "reset" method!')
                else:
                    project.resetAllFunctions()
            elif task == 'regenerate':
                if only_selected and hasattr(parameter, 'update'):
                    parameter.update(**run_args)
                elif only_selected and hasattr(parameter, 'regenerate'):
                    parameter.regenerate(**run_args)
                elif only_selected and not hasattr(parameter, 'regenerate') and not hasattr(parameter, 'update'):
                    raise Exception('Current parameter has no "regenerate" or "update" method!')
                else:
                    project.regenerate(**run_args)
            elif task == 'generate DocFiles':
                if only_selected and hasattr(parameter, 'generateDocumentationFiles'):
                    parameter.generateDocumentationFiles()
                elif only_selected and not hasattr(parameter, 'generateDocumentationFiles'):
                    raise Exception('Current parameter has no "generateDocumentationFiles" method!')
                else:
                    project.generateDocumentationFiles()
            elif task == 'delete DocFiles':
                if only_selected and hasattr(parameter, 'deleteDocumentationFiles'):
                    parameter.deleteDocumentationFiles()
                elif only_selected and not hasattr(parameter, 'deleteDocumentationFiles'):
                    raise Exception('Current parameter has no "deleteDocumentationFiles" method!')
                else:
                    project.deleteDocumentationFiles()
            else:
                project.setIndex(cur_index)
                raise Exception('Unknown option, choose from: {}'.format(options))

            project.setIndex(cur_index)
        print('Script finished successfully')
    else:
        print('Cancelled by user')


if __name__ == '__main__':
    """
    This script runs a task on all project indices.
    The task to execute can be selected from the GUI.

    This script needs to be executed in the SyMSpace Python Console.
    """

    _params = locals()
    _project = ScriptUtils.getProject(_params)
    _parameter = ScriptUtils.getParameter(_params)

    if _project is not None:
        ScriptUtils.run(main, _project, _parameter)
    else:
        ScriptUtils.showNoProjectWarning()
