#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10062 $
$LastChangedDate:: 2020-11-20 13:22:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2019, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
import json
from symspace.wrapper.symwrapper import SymProject
from symspace.console.script_utils import ScriptUtils


def main(project: SymProject) -> None:
    """
    Write a json file of the project data to the project directory

    Parameters
    ----------
    project : SymProject
        SyMSpace Project Instance

    """
    fname = project.getFile()
    dirpath = os.path.join(project.getDirectory(), 'JSONData')
    if not os.path.exists(dirpath):
        os.mkdir(dirpath)

    num = 1
    for fh in os.listdir(dirpath):
        if fh.startswith(fname):
            num += 1
    jstr = json.dumps(project.getRoot().toDict(detailed=True))
    fname = fname + '_{:04}.json'.format(num)

    with open(os.path.join(dirpath, fname), 'w') as fh:
        fh.write(jstr)

    print('JSON written')


if __name__ == '__main__':
    """
    This script writes a json file of the project data to the project directory.
    """
    _params = locals()
    _project = ScriptUtils.getProject(_params)
    main(_project)  # run without GUI-Messages
