#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10182 $
$LastChangedDate:: 2021-05-05 13:58:31 +0200#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import sys
import os
from symspace.osutils.pathutils import Paths


def set_QT_PLUGIN_PATH():
    """Try to set the QT Plugin Path

    Directory where the file "pyqt5qmlplugin.dll" can be found.

    This was an issue when using Anaconda Python Distributions with Jep,
    but might be resolved in later versions
    or when using standard Python distributions and packges from Python.org/pypi.org
    """
    qt_plugin_path = os.getenv('QT_PLUGIN_PATH')
    if qt_plugin_path is None:
        if sys.version_info[0] == 3 and sys.version_info[1] == 7:
            # print("Trying to set Environment Variable QT_PLUGIN_PATH in python 3.7")
            qt_plugin_path = os.path.join(Paths.getPythonRoot(), 'Library', 'plugins', 'PyQt5')
        else:
            qt_plugin_path = os.path.join(Paths.getPythonRoot(), 'Library', 'plugins')

        if os.path.isdir(qt_plugin_path):
            os.environ['QT_PLUGIN_PATH'] = qt_plugin_path
        # else:
        #     print("QT_PLUGIN_PATH is no directory: {}".format(qt_plugin_path))
    else:
        print("Environment Variable: QT_PLUGIN_PATH is already defined as: {}".format(qt_plugin_path))
