#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 9848 $
$LastChangedDate:: 2020-05-25 17:30:48 +0200#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import glob
import webbrowser

try:
    from junit2htmlreport import runner
except ImportError:
    '''exception for non standard package'''
    runner = None
    print('Unable to import "junit2htmlreport"')


def junit2html(xml_file: str, html_file: str = None, show: bool = False) -> str:
    """
    Wrapper function to create a html report from a junit xml-file

    Parameters
    ----------
    xml_file : str
        Input junit xml-file
    html_file: str
        Desired output html-file, None (Default)
    show: bool
        Open html in webbrowser

    Returns
    -------
    html_file: str
        Output html-file
    """
    if html_file is None:
        html_file = xml_file + '.html'

    args = [xml_file, html_file]
    runner.run(args)
    if show:
        webbrowser.open('file://' + html_file, new=2)
    return html_file


def junit2htmlMatrix(xml_file: str, html_file: str = None, show: bool = False) -> str:
    """
    Wrapper function to create a html report matrix from a junit xml-file

    Parameters
    ----------
    show
    xml_file : str
        Input junit xml-file
    html_file: str
        Desired output html-file, None (Default)
    show: bool
        Open html in webbrowser

    Returns
    -------
    html_file: str
        Output html-file
    """
    if html_file is None:
        html_file = xml_file + '.matrix.html'

    args = ['--report-matrix', html_file, xml_file]
    runner.run(args)
    if show:
        webbrowser.open('file://' + html_file, new=2)
    return html_file


def mergeJunitXML(folder: str, merged_xml_file: str = None) -> str:
    """
    Wrapper function to merge multiple junit xml-files

    Parameters
    ----------
    folder : str
        Directory of input junit xml-files
    merged_xml_file: str
        Desired output xml-file, None (Default)

    Returns
    -------
    merged_xml_file: str
        Output xml-file
    """
    if merged_xml_file is None:
        merged_xml_file = os.path.join(folder, 'merged.xml')

    xml_files = glob.glob(os.path.join(folder, '*.xml'))

    args = ['--merge', merged_xml_file]
    args.extend(xml_files)
    runner.run(args)
    return merged_xml_file


if __name__ == '__main__':
    _html_file = junit2htmlMatrix('X:\\junit.xml', show=True)
    print(_html_file)
