#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision$
$LastChangedDate::                           $

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

from rlcompleter import Completer


class SymCompleter:
    """
    Completes Python console input when pressing tab
    """
    def __init__(self):
        self.completer = Completer()
        self.text = ''
        self.index = 0

    def complete(self, text, forwared=True):
        # initialize completer
        if self.text != text:
            self.text = text
            self.index = 0
            self.completer.complete(self.text, 0)

        # calculate index
        if forwared:
            self.index += 1
        else:
            self.index -= 1

        # get matches
        if self.index == 0:
            ret = self.text
        elif self.index > 0:
            ret = self.completer.complete(self.text, self.index-1)
        else:
            ret = self.completer.complete(self.text, self.index)

        if ret is None:
            self.index = 0
            ret = self.text

        return ret


def completeTab(text, forwared=True):
    """
    Completes Python console input
    Tab can be pressed several times

    Parameters
    ----------
    text : str
        Console input text
    forwared : boolean
        Direction to traverse match list

    Returns
    -------
    ret : str
       Completed string
    """
    if not hasattr(completeTab, 'comp'):
        completeTab.comp = SymCompleter()

    return completeTab.comp.complete(text,forwared)


